/*
 * ============================================================================
 * (C) Copyright IBM Corporation 2006, 2007.  All Rights Reserved.
 * 
 * You may only copy, modify, and distribute these samples internally.
 * These samples have not been tested under all conditions and are provided
 * to you by IBM without obligation of support of any kind.
 *
 * IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
 * CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
 * CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
 * NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
 * ============================================================================
 */
 
def onList() {

	try {
		// Get configured DataManager for data access
		def data = zero.data.groovy.Manager.create('employee_db')

		// Retrieve employee records via Data Zero
		def result = data.queryArray('SELECT * FROM employees')
		
		request.view = 'JSON'
		request.json.output = result
		
		render()		
	} catch (Exception e){
		if (e.getCause() instanceof java.sql.SQLException) {
			request.status = HttpURLConnection.HTTP_INTERNAL_ERROR
			request.error.message = "The db may not have been initialized."
			request.view = "error"
			render()
		}
	}
}

def onCreate() {
	// Convert entity to JSON object
	def emp = zero.json.Json.decode(request.input[])

	// Get configured DataManager for data access
	def data = zero.data.groovy.Manager.create('employee_db')

	// Insert employee record via Data Zero APIs
	data.update("""
			INSERT INTO employees (username, firstname, lastname, location, phonenumber) 
			VALUES ($emp.username, $emp.firstname, $emp.lastname, $emp.location, $emp.phonenumber)
			""")

	// Set a Location header with URI to the new record
	locationUri = getRequestedUri(false) + '/' + emp['username']
	request.headers.out.Location = locationUri
	request.status = HttpURLConnection.HTTP_NO_CONTENT
}

def onRetrieve() {
	String username = request.params.employeesId[]

	// Get configured DataManager for data access
	def data = zero.data.groovy.Manager.create('employee_db')

	// Retrieve employee record via Data Zero
	def employeeRecord = data.queryFirst("SELECT * FROM employees WHERE username=$username")

	if(employeeRecord != null) {
		// Use ViewEngine JSON rendering
		request.view = 'JSON'
		request.json.output = employeeRecord
		render()
	} else {
  		// Error handling
  		request.status = HttpURLConnection.HTTP_NOT_FOUND
  		request.error.message = "username $username not found."
		request.view = "error"
		render()
	}
}
 
 def onUpdate() {
	// Convert entity to JSON object
	def emp = zero.json.Json.decode(request.input[])
	def employeeId = request.params.employeesId[]

	// Get configured DataManager for data access
	def data = zero.data.groovy.Manager.create('employee_db')

	// Update employee record via Data Zero
	data.update("""
			UPDATE employees SET firstname=$emp.firstname, lastname=$emp.lastname, 
			location=$emp.location, phonenumber=$emp.phonenumber
			WHERE username=$employeeId
	""")

	request.status = HttpURLConnection.HTTP_NO_CONTENT
 }
 
 def onDelete() {
	String username = request.params.employeesId[]
	 
 	// Get configured DataManager for data access
	def data = zero.data.groovy.Manager.create('employee_db')
	
	// Delete employee record via Data Zero
	data.update("DELETE FROM employees WHERE username=$username")

	request.status = HttpURLConnection.HTTP_NO_CONTENT
 }
 